const Main = imports.ui.main;

let delay = 200;
let timeout = null;

function onOverviewActivated() {
  Main.overview.dash.hide();
}

function onOverviewDeactivated() {
  timeout = setTimeout(() => {
    Main.overview.dash.show();
  }, delay);
}

class DockExtension {
  constructor() {
    this.showingSignalId = null;
    this.hiddenSignalId = null;
  }

  enable() {
    if (this.showingSignalId) {
      Main.overview.disconnect(this.showingSignalId);
    }
    if (this.hiddenSignalId) {
      Main.overview.disconnect(this.hiddenSignalId);
    }
    this.showingSignalId = Main.overview.connect('showing', onOverviewActivated);
    this.hiddenSignalId = Main.overview.connect('hiding', onOverviewDeactivated);
  }

  disable() {
    if (this.showingSignalId) {
      Main.overview.disconnect(this.showingSignalId);
      this.showingSignalId = null;
    }
    if (this.hiddenSignalId) {
      Main.overview.disconnect(this.hiddenSignalId);
      this.hiddenSignalId = null;
    }
    if(timeout){
      clearInterval(timeout);
    }
  }
}

function init() {
  return new DockExtension();
}
